% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ggpubr_options.R
\name{ggpubr_options}
\alias{ggpubr_options}
\title{Global Options for ggpubr}
\usage{
ggpubr_options()
}
\description{
Displays allowed global options in ggpubr.
}
\examples{

ggpubr_options()

}
