% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_format_utils.R
\name{format_single_p}
\alias{format_single_p}
\title{Format a Single P-Value}
\usage{
format_single_p(p, digits, leading.zero, decimal.mark)
}
\arguments{
\item{p}{Single numeric p-value.}

\item{digits}{Number of decimal places.}

\item{leading.zero}{Whether to include leading zero.}

\item{decimal.mark}{Character string to use as the decimal mark.}
}
\value{
Formatted character string.
}
\description{
Internal helper function to format a single p-value.
}
\keyword{internal}
