% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_format_utils.R
\name{list_p_format_styles}
\alias{list_p_format_styles}
\title{List Available P-Value Format Styles}
\usage{
list_p_format_styles()
}
\value{
A data frame with columns: style, digits, leading.zero, min.threshold,
  use.scientific, description.
}
\description{
Returns a data frame describing all available p-value formatting styles.
}
\examples{
list_p_format_styles()

}
