% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/p_format_utils.R
\name{get_p_format_style}
\alias{get_p_format_style}
\title{Get P-Value Format Style Settings}
\usage{
get_p_format_style(style = "default")
}
\arguments{
\item{style}{Character string specifying the style. One of: "default", "apa",
"nejm", "lancet", "ama", "graphpad", "scientific".}
}
\value{
A list containing: digits, leading.zero, min.threshold, use.scientific, description.
}
\description{
Returns the settings for a given p-value format style.
}
\examples{
get_p_format_style("apa")
get_p_format_style("nejm")

}
